@@ -1,6 +1,6 @@
 context("Test helper functions")
 
-xml <- xmlParse("test.xml")
+xml <- xmlParse("data/test.xml")
 
 test_that("'xvalue' and 'xname' work as advertised", {
   expect_equal(xvalue(xml, "//Id"), c("23927984", "23903989"))
@@ -15,4 +15,4 @@ test_that("Setting defaults with 'value' work as advertised", {
   expect_equal(xvalue(xml, "//bla", default=NULL), NULL)
   expect_equal(xvalue(xml, "//bla", default=0), "0")
   expect_equal(xvalue(xml, "//bla", as="numeric", default=0), 0)
-})
\ No newline at end of file
+})
